
# Slot: decreases synthesis of


holds between two molecular entities where the action or effect of one decreases the rate of chemical synthesis of the other

URI: [biolink:decreases_synthesis_of](https://w3id.org/biolink/vocab/decreases_synthesis_of)


## Domain and Range

[MolecularEntity](MolecularEntity.md) &#8594;  <sub>0..\*</sub> [MolecularEntity](MolecularEntity.md)

## Parents

 *  is_a: [affects synthesis of](affects_synthesis_of.md)

## Children


## Used by


## Other properties

|  |  |  |
| --- | --- | --- |
| **In Subsets:** | | translator_minimal |
| **Exact Mappings:** | | CTD:decreases_synthesis_of |
|  | | GAMMA:inhibition_of_synthesis |

